@@ -5,13 +5,11 @@ __date__ = '8/22/12'
 
 @task()
 def thumbnail_task(photo):
+    # USe new regenerate method.
     photo.make_thumbnails()
     photo.thumbs_created = True
     photo.save()
 
 @task()
 def thumbnail_cleanup_task(photo):
-    from sorl.thumbnail import delete
-    delete(photo.image, delete_file=False)
-    photo.thumbs_created = False
-    photo.save()
\ No newline at end of file
+    photo.clear_thumbnails()
\ No newline at end of file
